@@ -12,10 +12,22 @@ def pytest_addoption(parser):
     group.addoption("--migrateci-location")
     group.addoption("--migrateci-storage")
     group.addoption("--migrateci-depth", type=int)
+    group.addoption("--migrateci-verbose", type=int)
 
 
 def pytest_configure(config):
-    if not config.option.migrateci:
+    if config.option.help or not config.option.migrateci:
+        return
+
+    # Make pytest-django never create db because migrateci already do it.
+    # It must be changed even inside the xdist worker.
+    create_db = config.option.create_db
+    config.option.create_db = False
+
+    # I want to execute only on controller (without worker_id) to avoid multiple runs.
+    # It also works without pytest-xdist.
+    worker_id = os.environ.get("PYTEST_XDIST_WORKER")
+    if worker_id is not None:
         return
 
     try:
@@ -26,13 +38,11 @@ def pytest_configure(config):
         # The pytest-django lib is not installed, do nothing and hope for the best.
         db_unblock = nullcontext
 
-    # I want to execute only on controller (without worker_id) to avoid multiple runs.
-    # It also works without pytest-xdist.
-    worker_id = os.environ.get("PYTEST_XDIST_WORKER")
-    if worker_id is not None:
-        return
+    verbosity = config.option.migrateci_verbose
+    if verbosity is None:
+        verbosity = config.option.verbose
 
-    command_kwargs = {"pytest": True, "verbosity": config.option.verbose}
+    command_kwargs = {"pytest": True}
 
     # Option numprocesses is from pytest-xdist and doesn't exist if it is not installed.
     parallel = getattr(config.option, "numprocesses", None)
@@ -40,11 +50,6 @@ def pytest_configure(config):
         command_kwargs["parallel"] = parallel
 
     # Option reuse_db is from pytest-django.
-    create_db = config.option.create_db
-
-    # Make pytest-django never create db because migrateci already do it.
-    config.option.create_db = False
-
     reuse_db = getattr(config.option, "reuse_db", False)
     if reuse_db and not create_db:
         command_kwargs["reuse_db"] = True
@@ -53,8 +58,10 @@ def pytest_configure(config):
         command_kwargs["location"] = config.option.migrateci_location
     if config.option.migrateci_storage:
         command_kwargs["storage_class"] = config.option.migrateci_storage
-    if config.option.migrateci_depth:
+    if config.option.migrateci_depth is not None:
         command_kwargs["depth"] = config.option.migrateci_depth
+    if verbosity is not None:
+        command_kwargs["verbosity"] = verbosity
 
     with db_unblock():
         call_command("migrateci", **command_kwargs)
